pub struct UdpFlowState {
pub status: ConversationStatus,
}Expand description
UDP pseudo-conversation state.
UDP is connectionless, so conversations are tracked purely via timeout heuristics. A conversation is considered active as long as packets continue arriving within the configured timeout window.
Fields
status: ConversationStatusImplementations
Sourceimpl UdpFlowState
impl UdpFlowState
pub fn new() -> Self
Sourcepub fn process_packet(&mut self)
pub fn process_packet(&mut self)
Update state when a new packet is received.
Sourcepub fn check_timeout(
&self,
last_seen: Duration,
now: Duration,
config: &FlowConfig,
) -> bool
pub fn check_timeout( &self, last_seen: Duration, now: Duration, config: &FlowConfig, ) -> bool
Check whether this flow has timed out.