LayerBinding

Struct LayerBinding 

pub struct LayerBinding {
    pub upper: LayerKind,
    pub lower: LayerKind,
    pub field_name: &'static str,
    pub field_value: u16,
}
Describes a binding between two layers.

When the upper layer is placed on top of the lower layer, the specified field of the lower layer should be set to the given value.

Fields

upper: LayerKind

The layer being placed on top

lower: LayerKind

The layer below

field_name: &'static str

The field name in the lower layer to set

field_value: u16

The value to set (as u16 for simplicity; can be cast)

Implementations

Source

impl LayerBinding

pub const fn new( lower: LayerKind, upper: LayerKind, field_name: &'static str, field_value: u16, ) -> Self