Dot11Builder

Struct Dot11Builder 

pub struct Dot11Builder {
    pub proto: u8,
    pub frame_type: u8,
    pub subtype: u8,
    pub flags: u8,
    pub duration: u16,
    pub addr1: MacAddress,
    pub addr2: MacAddress,
    pub addr3: MacAddress,
    pub addr4: Option<MacAddress>,
    pub seq_ctrl: u16,
    pub body: Vec<u8>,
    pub with_fcs: bool,
}
Builder for constructing 802.11 frames with a fluent API.

Example

let frame = Dot11Builder::new()
    .frame_type(types::frame_type::MANAGEMENT)
    .subtype(types::mgmt_subtype::BEACON)
    .addr1(MacAddress::BROADCAST)
    .addr2(bssid)
    .addr3(bssid)
    .build();

Fields

proto: u8

Protocol version (default 0).

frame_type: u8

Frame type (Management/Control/Data).

subtype: u8

Frame subtype.

flags: u8

Flags byte (to_DS, from_DS, retry, etc.).

duration: u16

Duration/ID field.

addr1: MacAddress

Address 1 (receiver/destination).

addr2: MacAddress

Address 2 (transmitter/source).

addr3: MacAddress

Address 3 (BSSID or other).

addr4: Option<MacAddress>

Address 4 (only in WDS mode).

seq_ctrl: u16

Sequence Control field.

body: Vec<u8>

Frame body payload (management body, data, etc.).

with_fcs: bool

Whether to append FCS.

Implementations

Source

impl Dot11Builder

pub fn new() -> Self

Create a new builder with default values.

pub fn proto(self, proto: u8) -> Self

Set the protocol version (usually 0).

pub fn frame_type(self, ft: u8) -> Self

Set the frame type.

pub fn subtype(self, st: u8) -> Self

Set the frame subtype.

pub fn flags(self, flags: u8) -> Self

Set the flags byte.

pub fn to_ds(self, val: bool) -> Self

Set the to_DS flag.

pub fn from_ds(self, val: bool) -> Self

Set the from_DS flag.

pub fn retry(self, val: bool) -> Self

Set the retry flag.

pub fn protected(self, val: bool) -> Self

Set the protected frame flag.

pub fn duration(self, dur: u16) -> Self

Set the Duration/ID field.

pub fn addr1(self, mac: MacAddress) -> Self

Set Address 1 (receiver/destination).

pub fn addr2(self, mac: MacAddress) -> Self

Set Address 2 (transmitter/source).

pub fn addr3(self, mac: MacAddress) -> Self

Set Address 3 (BSSID or other).

pub fn addr4(self, mac: MacAddress) -> Self

Set Address 4 (WDS mode).

pub fn seq_ctrl(self, sc: u16) -> Self

Set the Sequence Control field directly.

pub fn seq_num(self, seq: u16, frag: u8) -> Self

Set sequence number and fragment number.

pub fn body(self, body: Vec<u8>) -> Self

Set the frame body (payload after the header).

pub fn with_fcs(self, enable: bool) -> Self

Enable FCS (Frame Check Sequence) appending.

pub fn header_size(&self) -> usize

Calculate the header size based on frame type and addresses.

pub fn build(&self) -> Vec<u8>

Build the frame bytes.

pub fn beacon(bssid: MacAddress) -> Self

Create a Beacon frame builder.

pub fn probe_request(src: MacAddress) -> Self

Create a Probe Request frame builder.

pub fn probe_response(dst: MacAddress, bssid: MacAddress) -> Self

Create a Probe Response frame builder.

pub fn authentication( dst: MacAddress, src: MacAddress, bssid: MacAddress, ) -> Self

Create an Authentication frame builder.

pub fn deauthentication( dst: MacAddress, src: MacAddress, bssid: MacAddress, ) -> Self

Create a Deauthentication frame builder.

pub fn assoc_request(dst: MacAddress, src: MacAddress) -> Self

Create an Association Request frame builder.

pub fn ack(dst: MacAddress) -> Self

Create an ACK frame builder.

pub fn rts(dst: MacAddress, src: MacAddress) -> Self

Create an RTS frame builder.

pub fn cts(dst: MacAddress) -> Self

Create a CTS frame builder.

pub fn data_to_ap(bssid: MacAddress, src: MacAddress, dst: MacAddress) -> Self

Create a Data frame builder (to AP: to_DS=1).

pub fn data_from_ap(dst: MacAddress, bssid: MacAddress, src: MacAddress) -> Self

Create a Data frame builder (from AP: from_DS=1).

pub fn qos_data_to_ap( bssid: MacAddress, src: MacAddress, dst: MacAddress, ) -> Self

Create a QoS Data frame builder (to AP: to_DS=1).

pub fn data_wds( ra: MacAddress, ta: MacAddress, da: MacAddress, sa: MacAddress, ) -> Self

Create a WDS Data frame builder (to_DS=1, from_DS=1).

pub fn build_beacon( bssid: MacAddress, timestamp: u64, beacon_interval: u16, capability: u16, ies: &[Dot11Elt], ) -> Vec<u8>

Build a beacon frame with the given body parameters and IEs.

pub fn build_probe_request(src: MacAddress, ies: &[Dot11Elt]) -> Vec<u8>

Build a probe request frame with the given IEs.

pub fn build_probe_response( dst: MacAddress, bssid: MacAddress, timestamp: u64, beacon_interval: u16, capability: u16, ies: &[Dot11Elt], ) -> Vec<u8>

Build a probe response frame with the given body parameters and IEs.

pub fn build_auth( dst: MacAddress, src: MacAddress, bssid: MacAddress, algo: u16, seqnum: u16, status: u16, ) -> Vec<u8>

Build an authentication frame.

pub fn build_deauth( dst: MacAddress, src: MacAddress, bssid: MacAddress, reason: u16, ) -> Vec<u8>

Build a deauthentication frame.

pub fn build_assoc_request( dst: MacAddress, src: MacAddress, capability: u16, listen_interval: u16, ies: &[Dot11Elt], ) -> Vec<u8>

Build an association request frame.

pub fn build_assoc_response( dst: MacAddress, bssid: MacAddress, capability: u16, status: u16, aid: u16, ies: &[Dot11Elt], ) -> Vec<u8>

Build an association response frame.

pub fn build_qos_data( bssid: MacAddress, src: MacAddress, dst: MacAddress, tid: u8, payload: &[u8], ) -> Vec<u8>

Build a data frame with QoS header.