Module control

Module control 

IEEE 802.11 control frame subtypes.

Control frames are used for assisting delivery of data and management frames. Most control frames have minimal or no body beyond the 802.11 header addresses.

Structs

Dot11Ack
802.11 ACK frame.
Dot11BlockAck
802.11 Block Ack (BA) frame body.
Dot11BlockAckReq
802.11 Block Ack Request (BAR) frame body.
Dot11CFEnd
802.11 CF-End frame body.
Dot11CTS
802.11 CTS (Clear To Send) frame.
Dot11PSPoll
802.11 PS-Poll frame body.
Dot11RTS
802.11 RTS (Request To Send) frame.

Constants

BAR_FIXED_LEN
BA_BASIC_BITMAP_LEN
BA_MIN_FIXED_LEN