Module management

Module management 

IEEE 802.11 management frame subtypes.

Management frames are used for establishing and maintaining communications. This module provides parsers for all major management frame subtypes including Beacon, Probe Request/Response, Authentication, Association, etc.

Structs

Dot11ATIM
802.11 ATIM (Announcement Traffic Indication Message) frame body.
Dot11Action
802.11 Action frame body.
Dot11AssocReq
802.11 Association Request frame body.
Dot11AssocResp
802.11 Association Response frame body.
Dot11Auth
802.11 Authentication frame body.
Dot11Beacon
802.11 Beacon frame body.
Dot11Deauth
802.11 Deauthentication frame body.
Dot11Disas
802.11 Disassociation frame body.
Dot11ProbeReq
802.11 Probe Request frame body.
Dot11ProbeResp
802.11 Probe Response frame body.
Dot11ReassocReq
802.11 Reassociation Request frame body.
Dot11ReassocResp
802.11 Reassociation Response frame body (same as Association Response).

Constants

ACTION_MIN_LEN
ASSOC_REQ_FIXED_LEN
ASSOC_RESP_FIXED_LEN
AUTH_FIXED_LEN
BEACON_FIXED_LEN
Beacon fixed fields length.
DEAUTH_FIXED_LEN
DISAS_FIXED_LEN
REASSOC_REQ_FIXED_LEN