RadioTap header implementation for IEEE 802.11 frames.
RadioTap is a de facto standard for 802.11 frame injection and reception.
It provides a flexible, extensible header format that precedes the actual
802.11 frame and carries metadata like signal strength, channel, and rate.
Reference: https://www.radiotap.org/
Modules
- offsets
RadioTapheader field offsets.
Structs
- Radio
TapBuilder - Builder for constructing
RadioTapheaders. - Radio
TapFields - Parsed
RadioTapfield values. - Radio
TapLayer RadioTaplayer - a zero-copy view into theRadioTapheader.
Constants
- RADIOTAP_
MIN_ HEADER_ LEN - Minimum
RadioTapheader length: version(1) + pad(1) + len(2) + present(4) = 8 bytes.