BeaconPayload

Struct BeaconPayload 

pub struct BeaconPayload {
Show 14 fields pub beacon_order: u8, pub superframe_order: u8, pub final_cap_slot: u8, pub battery_life_ext: bool, pub pan_coordinator: bool, pub assoc_permit: bool, pub gts_desc_count: u8, pub gts_permit: bool, pub gts_dir_mask: u8, pub gts_descriptors: Vec<GtsDescriptor>, pub pa_num_short: u8, pub pa_num_long: u8, pub pa_short_addresses: Vec<u16>, pub pa_long_addresses: Vec<u64>,
}
Parsed beacon frame payload.

Fields

beacon_order: u8

Beacon order (4 bits).

superframe_order: u8

Superframe order (4 bits).

final_cap_slot: u8

Final CAP slot (4 bits).

battery_life_ext: bool

Battery life extension (1 bit).

pan_coordinator: bool

PAN coordinator (1 bit).

assoc_permit: bool

Association permit (1 bit).

gts_desc_count: u8

GTS descriptor count (3 bits).

gts_permit: bool

GTS permit (1 bit).

gts_dir_mask: u8

GTS direction mask (7 bits), present if gts_desc_count > 0.

gts_descriptors: Vec<GtsDescriptor>

GTS descriptors (3 bytes each).

pa_num_short: u8

Number of short addresses pending (3 bits).

pa_num_long: u8

Number of extended (long) addresses pending (3 bits).

pa_short_addresses: Vec<u16>

Short addresses pending (2 bytes each).

pa_long_addresses: Vec<u64>

Long addresses pending (8 bytes each).

Implementations

Source

impl BeaconPayload

pub fn parse(buf: &[u8], offset: usize) -> Result<(Self, usize), FieldError>

Parse a beacon payload from the buffer at the given offset. Returns the parsed payload and the number of bytes consumed.

pub fn build(&self) -> Vec<u8>

Build the beacon payload bytes.

pub fn summary(&self) -> String

Get a human-readable summary of this beacon.