AuxSecurityHeader

Struct AuxSecurityHeader 

pub struct AuxSecurityHeader {
    pub security_level: u8,
    pub key_id_mode: u8,
    pub reserved: u8,
    pub frame_counter: u32,
    pub key_source: u64,
    pub key_index: Option<u8>,
}
Security Control field bit layout (1 byte): Bits 0-2: Security Level (3 bits) Bits 3-4: Key Identifier Mode (2 bits) Bits 5-7: Reserved (3 bits) Parsed representation of an Auxiliary Security Header.

Fields

security_level: u8

Security level (3 bits).

key_id_mode: u8

Key identifier mode (2 bits).

reserved: u8

Reserved bits (3 bits).

frame_counter: u32

Frame counter (4 bytes).

key_source: u64

Key source (0, 4, or 8 bytes depending on key_id_mode).

key_index: Option<u8>

Key index (1 byte, present if key_id_mode != 0).

Implementations

Source

impl AuxSecurityHeader

pub fn len(&self) -> usize

Total byte length of this security header.

pub fn compute_len(security_control: u8) -> usize

Compute the byte length of the security header given the security control byte (first byte of the header).

pub fn parse(buf: &[u8], offset: usize) -> Result<(Self, usize), FieldError>

Parse an Auxiliary Security Header from the buffer at the given offset. Returns the parsed header and the number of bytes consumed.

pub fn build(&self) -> Vec<u8>

Build the security header bytes.

pub fn write_into( &self, buf: &mut [u8], offset: usize, ) -> Result<usize, FieldError>

Write the security header into a buffer at the given offset. Returns the number of bytes written.