FieldValue

Enum FieldValue 

pub enum FieldValue {
Show 15 variants U8(u8), U16(u16), U32(u32), U64(u64), I8(i8), I16(i16), I32(i32), I64(i64), Bool(bool), Mac(MacAddress), Ipv4(Ipv4Addr), Ipv6(Ipv6Addr), Bytes(Vec<u8>), Str(String), List(Vec<FieldValue>),
}
A dynamically-typed field value.

Variants



U8(u8)



U16(u16)



U32(u32)



U64(u64)



I8(i8)



I16(i16)



I32(i32)



I64(i64)



Bool(bool)



Mac(MacAddress)



Ipv4(Ipv4Addr)



Ipv6(Ipv6Addr)



Bytes(Vec<u8>)



Str(String)



List(Vec<FieldValue>)

Implementations

Source

impl FieldValue

pub fn read(buf: &[u8], desc: &FieldDesc) -> Result<Self, FieldError>

Read a field value from buffer using the field descriptor.

pub fn read_bytes( buf: &[u8], offset: usize, len: usize, ) -> Result<Self, FieldError>

Read a bytes field with explicit length

pub fn write(&self, buf: &mut [u8], desc: &FieldDesc) -> Result<(), FieldError>

Write a field value to buffer using the field descriptor.

pub fn write_bytes( bytes: &[u8], buf: &mut [u8], offset: usize, ) -> Result<(), FieldError>

Write bytes to buffer at offset

pub const fn type_name(&self) -> &'static str

pub fn as_u8(&self) -> Option<u8>

pub fn as_u16(&self) -> Option<u16>

pub fn as_u32(&self) -> Option<u32>

pub fn as_u64(&self) -> Option<u64>

pub fn as_mac(&self) -> Option<MacAddress>

pub fn as_ipv4(&self) -> Option<Ipv4Addr>

pub fn as_ipv6(&self) -> Option<Ipv6Addr>

pub fn as_bytes(&self) -> Option<&[u8]>

pub fn as_i8(&self) -> Option<i8>

pub fn as_i16(&self) -> Option<i16>

pub fn as_i32(&self) -> Option<i32>

pub fn as_i64(&self) -> Option<i64>

pub fn as_bool(&self) -> Option<bool>

pub fn as_str(&self) -> Option<&str>

pub fn as_list(&self) -> Option<&[FieldValue]>

pub fn to_bytes(&self) -> Vec<u8>

Convert to bytes representation