pub struct Http2Builder { /* private fields */ }Expand description
Builder for a complete HTTP/2 connection sequence.
Optionally includes the client connection preface, followed by one or more frames.
Example
use stackforge_core::layer::http2::builder::{Http2Builder, Http2FrameBuilder};
let bytes = Http2Builder::new()
.frame(Http2FrameBuilder::settings())
.frame(Http2FrameBuilder::settings_ack())
.build();Implementations
Sourceimpl Http2Builder
impl Http2Builder
Sourcepub fn without_preface() -> Self
pub fn without_preface() -> Self
Create a builder without the connection preface.
Sourcepub fn frame(self, f: Http2FrameBuilder) -> Self
pub fn frame(self, f: Http2FrameBuilder) -> Self
Add a frame to the sequence.
Sourcepub fn header_size(&self) -> usize
pub fn header_size(&self) -> usize
Get the total byte size of the built output.