pub struct HpackDecoder { /* private fields */ }Expand description
HPACK decoder with dynamic table state.
This decoder maintains a dynamic table across multiple calls, allowing header compression state to be shared within an HTTP/2 connection.
Implementations
Sourceimpl HpackDecoder
impl HpackDecoder
Sourcepub fn with_max_size(max_table_size: usize) -> Self
pub fn with_max_size(max_table_size: usize) -> Self
Create a new HPACK decoder with a specific max table size.
Sourcepub fn set_max_table_size(&mut self, size: usize)
pub fn set_max_table_size(&mut self, size: usize)
Update the maximum table size (e.g., from SETTINGS_HEADER_TABLE_SIZE).
Sourcepub fn dynamic_table_len(&self) -> usize
pub fn dynamic_table_len(&self) -> usize
Returns the number of entries currently in the dynamic table.
Sourcepub fn dynamic_table_current_size(&self) -> usize
pub fn dynamic_table_current_size(&self) -> usize
Returns the current size (in bytes) of the dynamic table.
Sourcepub fn dynamic_table_entries(&self) -> &[(String, String)]
pub fn dynamic_table_entries(&self) -> &[(String, String)]
Returns the entries in the dynamic table as (name, value) string slices. Entries are ordered most-recently-added first (index 62 = first entry).