Module icmp

Module icmp 

ICMP (Internet Control Message Protocol) layer implementation.

This module provides types and functions for working with ICMP packets, including parsing, field access, and checksum calculation.

Re-exports

pub use builder::IcmpBuilder;
pub use checksum::icmp_checksum;
pub use checksum::verify_icmp_checksum;
pub use error::ERROR_MIN_PAYLOAD;
pub use error::ERROR_TYPES;
pub use error::error_payload_offset;
pub use error::is_error_type;
pub use extensions::InterfaceInformation;
pub use extensions::IpAddr;
pub use extensions::class_name as extension_class_name;
pub use extensions::has_extensions;
pub use extensions::parse_extension_header;
pub use extensions::parse_extension_object;
pub use extensions::parse_interface_information;
pub use types::ICMP_ANSWERS;
pub use types::code_name;
pub use types::type_name;

Modules

builder
ICMP packet builder.
checksum
ICMP checksum calculation and verification.
error
ICMP error packet handling.
extensions
ICMP Extensions Framework (RFC 4884)
offsets
Field offsets within the ICMP header.
types
ICMP type and code constants.

Structs

IcmpLayer
ICMP layer representation.

Constants

ICMP_MIN_HEADER_LEN
ICMP minimum header length (8 bytes).

Statics

FIELDS
ICMP field descriptors for dynamic access.