ICMPv6 (Internet Control Message Protocol for IPv6) layer implementation.
This module provides types and functions for working with ICMPv6 packets,
including parsing, field access, and checksum calculation using the IPv6
pseudo-header.
Re-exports
pub use builder::Icmpv6Builder;
Modules
- builder
ICMPv6packet builder.- offsets
- Field offsets within the
ICMPv6header. - types
ICMPv6type constants.
Structs
- Icmpv6
Layer - An
ICMPv6layer view.
Constants
- ICMP
V6_ MIN_ HEADER_ LEN ICMPv6minimum header length (8 bytes).
Functions
- icmpv6_
checksum - Compute the
ICMPv6checksum over the IPv6 pseudo-header +ICMPv6data. - verify_
icmpv6_ checksum - Verify an
ICMPv6checksum.