Module ttl

Module ttl 

TTL (Time To Live) utilities.

Provides functions to guess the original TTL and number of hops based on the current TTL value.

Functions

estimate_hops
Estimate the number of hops the packet has traveled.
estimate_original
Estimate the original TTL based on the current TTL.