Pop3Layer

Struct Pop3Layer 

pub struct Pop3Layer {
    pub index: LayerIndex,
}
A zero-copy view into a POP3 layer within a packet buffer.

Fields

index: LayerIndex

Implementations

Source

impl Pop3Layer

pub fn new(index: LayerIndex) -> Self

pub fn at_start(len: usize) -> Self

pub fn is_response(&self, buf: &[u8]) -> bool

Returns true if this is a server response (starts with +OK or -ERR).

pub fn is_ok(&self, buf: &[u8]) -> bool

Returns true if this is a positive response (+OK).

pub fn is_err_response(&self, buf: &[u8]) -> bool

Returns true if this is a negative response (-ERR).

pub fn response_text(&self, buf: &[u8]) -> Result<String, FieldError>

Returns the response text after +OK or -ERR (trimmed).

Errors

Returns FieldError::InvalidValue if the payload is not valid UTF-8 or does not begin with +OK or -ERR.

pub fn command(&self, buf: &[u8]) -> Result<String, FieldError>

Returns the command verb (for client commands).

Errors

Returns FieldError::InvalidValue if the payload is not valid UTF-8.

pub fn args(&self, buf: &[u8]) -> Result<String, FieldError>

Returns the command arguments.

Errors

Returns FieldError::InvalidValue if the payload is not valid UTF-8.

pub fn raw(&self, buf: &[u8]) -> String

Returns the raw payload.

pub fn get_field( &self, buf: &[u8], name: &str, ) -> Option<Result<FieldValue, FieldError>>