pub trait IntoLayerStackEntry {
// Required method
fn into_layer_stack_entry(self) -> LayerStackEntry;
}Expand description
Trait for types that can be converted into a LayerStackEntry.
pub trait IntoLayerStackEntry {
// Required method
fn into_layer_stack_entry(self) -> LayerStackEntry;
}Trait for types that can be converted into a LayerStackEntry.