pub struct LayerIndex {
pub kind: LayerKind,
pub start: usize,
pub end: usize,
}Expand description
Index information for a layer within a packet buffer.
Fields
kind: LayerKindstart: usizeend: usizeImplementations
Sourceimpl LayerIndex
impl LayerIndex
pub const fn new(kind: LayerKind, start: usize, end: usize) -> Self
pub const fn range(&self) -> Range<usize>
pub const fn len(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn slice<'a>(&self, buf: &'a [u8]) -> &'a [u8] ⓘ
pub fn slice<'a>(&self, buf: &'a [u8]) -> &'a [u8] ⓘ
Get the bytes for this layer from a buffer