Module udp

Module udp 

UDP (User Datagram Protocol) layer implementation.

This module provides types and functions for working with UDP packets, including parsing, field access, and checksum calculation.

Re-exports

pub use builder::UdpBuilder;
pub use checksum::udp_checksum_ipv4;
pub use checksum::udp_checksum_ipv6;
pub use checksum::verify_udp_checksum_ipv4;
pub use checksum::verify_udp_checksum_ipv6;

Modules

builder
UDP packet builder.
checksum
UDP checksum calculation and verification.
offsets
Field offsets within the UDP header.

Structs

UdpLayer
UDP layer representation.

Constants

UDP_HEADER_LEN
UDP header length (8 bytes fixed).

Statics

FIELDS
UDP field descriptors for dynamic access.