configure_thread_pool

Function configure_thread_pool 

pub fn configure_thread_pool(num_threads: usize) -> Result<()>
Configure the global Rayon thread pool.

Call this once at startup to control the number of worker threads. If not called, Rayon defaults to the number of logical CPUs.

Errors

Returns an error if the thread pool has already been initialized.