pub struct CanonicalKey {
pub addr_a: IpAddr,
pub addr_b: IpAddr,
pub port_a: u16,
pub port_b: u16,
pub protocol: TransportProtocol,
pub vlan_id: Option<u16>,
}Expand description
Bidirectional canonical conversation key.
Uses Wireshark-style canonical ordering: the smaller IP address is always
addr_a with its corresponding port as port_a. This ensures that both
directions of a conversation hash to the same key.
Fields
addr_a: IpAddrThe smaller IP address (or first if equal, then by port).
addr_b: IpAddrThe larger IP address.
port_a: u16Port corresponding to addr_a.
port_b: u16Port corresponding to addr_b.
protocol: TransportProtocolTransport protocol.
vlan_id: Option<u16>Optional VLAN ID for deinterlacing.
Implementations
Sourceimpl CanonicalKey
impl CanonicalKey
Sourcepub fn new(
src_ip: IpAddr,
dst_ip: IpAddr,
src_port: u16,
dst_port: u16,
protocol: TransportProtocol,
vlan_id: Option<u16>,
) -> (Self, FlowDirection)
pub fn new( src_ip: IpAddr, dst_ip: IpAddr, src_port: u16, dst_port: u16, protocol: TransportProtocol, vlan_id: Option<u16>, ) -> (Self, FlowDirection)
Create a new canonical key with deterministic ordering.
Returns the key and the direction of the original packet relative to the canonical ordering.