pub fn apply_binding(
lower: LayerKind,
upper: LayerKind,
) -> Option<(&'static str, u16)>Expand description
Apply binding to set the appropriate field when stacking layers.
Returns the field name and value that should be set, if a binding exists.