pub struct LayerBinding {
pub upper: LayerKind,
pub lower: LayerKind,
pub field_name: &'static str,
pub field_value: u16,
}Expand description
Describes a binding between two layers.
When the upper layer is placed on top of the lower layer, the specified field of the lower layer should be set to the given value.
Fields
upper: LayerKindThe layer being placed on top
lower: LayerKindThe layer below
field_name: &'static strThe field name in the lower layer to set
field_value: u16The value to set (as u16 for simplicity; can be cast)
Implementations