IEEE 802.11 data frame subtypes and QoS handling.
Data frames carry the actual payload data in 802.11 networks.
QoS data frames include a 2-byte QoS Control field after the
802.11 header (and before the payload/security headers).
Structs
- AMsdu
Subframe - A single A-MSDU subframe.
- Dot11
QoS - 802.11
QoSControl field (2 bytes).
Constants
- AMSDU_
SUBFRAME_ HEADER_ LEN - A-MSDU subframe header length: DA(6) + SA(6) + Length(2) = 14.
- LLC_
SNAP_ LEN - LLC/SNAP header length.
- LLC_
SNAP_ PREFIX - LLC/SNAP header: AA:AA:03:00:00:00 followed by 2-byte
EtherType. - QOS_
CTRL_ LEN QoSControl field length.
Functions
- is_
llc_ snap - Check if the data at the given offset starts with an LLC/SNAP header.
- llc_
snap_ ethertype - Extract the
EtherTypefrom an LLC/SNAP header at the given offset.