IEEE 802.11 management frame subtypes.
Management frames are used for establishing and maintaining communications. This module provides parsers for all major management frame subtypes including Beacon, Probe Request/Response, Authentication, Association, etc.
Structs
- Dot11ATIM
- 802.11 ATIM (Announcement Traffic Indication Message) frame body.
- Dot11
Action - 802.11 Action frame body.
- Dot11
Assoc Req - 802.11 Association Request frame body.
- Dot11
Assoc Resp - 802.11 Association Response frame body.
- Dot11
Auth - 802.11 Authentication frame body.
- Dot11
Beacon - 802.11 Beacon frame body.
- Dot11
Deauth - 802.11 Deauthentication frame body.
- Dot11
Disas - 802.11 Disassociation frame body.
- Dot11
Probe Req - 802.11 Probe Request frame body.
- Dot11
Probe Resp - 802.11 Probe Response frame body.
- Dot11
Reassoc Req - 802.11 Reassociation Request frame body.
- Dot11
Reassoc Resp - 802.11 Reassociation Response frame body (same as Association Response).