IEEE 802.15.4 Auxiliary Security Header parsing and building.
The Auxiliary Security Header is present when the Security Enabled bit is set in the Frame Control Field. It consists of:
- Security Control (1 byte)
- Frame Counter (4 bytes, LE)
- Key Identifier (variable length, based on Key Identifier Mode)
Structs
- AuxSecurity
Header - Security Control field bit layout (1 byte): Bits 0-2: Security Level (3 bits) Bits 3-4: Key Identifier Mode (2 bits) Bits 5-7: Reserved (3 bits) Parsed representation of an Auxiliary Security Header.
Functions
- read_
key_ id_ mode - Read the key identifier mode from a Security Control byte.
- read_
security_ level - Read the security level from a Security Control byte.