ICMPv6 (Internet Control Message Protocol for IPv6) layer implementation.
This module provides types and functions for working with ICMPv6 packets, including parsing, field access, and checksum calculation using the IPv6 pseudo-header.
Re-exports
pub use builder::Icmpv6Builder;
Modules
- builder
- ICMPv6 packet builder.
- offsets
- Field offsets within the ICMPv6 header.
- types
- ICMPv6 type constants.
Structs
- Icmpv6
Layer - An ICMPv6 layer view.
Constants
- ICMP
V6_ MIN_ HEADER_ LEN - ICMPv6 minimum header length (8 bytes).
Functions
- icmpv6_
checksum - Compute the ICMPv6 checksum over the IPv6 pseudo-header + ICMPv6 data.
- verify_
icmpv6_ checksum - Verify an ICMPv6 checksum.