pub struct Pop3Layer {
pub index: LayerIndex,
}Expand description
A zero-copy view into a POP3 layer within a packet buffer.
Fields
index: LayerIndexImplementations
Sourceimpl Pop3Layer
impl Pop3Layer
pub fn new(index: LayerIndex) -> Self
pub fn at_start(len: usize) -> Self
Sourcepub fn is_response(&self, buf: &[u8]) -> bool
pub fn is_response(&self, buf: &[u8]) -> bool
Returns true if this is a server response (starts with +OK or -ERR).
Sourcepub fn is_err_response(&self, buf: &[u8]) -> bool
pub fn is_err_response(&self, buf: &[u8]) -> bool
Returns true if this is a negative response (-ERR).
Sourcepub fn response_text(&self, buf: &[u8]) -> Result<String, FieldError>
pub fn response_text(&self, buf: &[u8]) -> Result<String, FieldError>
Returns the response text after +OK or -ERR (trimmed).
Errors
Returns FieldError::InvalidValue if the payload is not valid UTF-8 or
does not begin with +OK or -ERR.
Sourcepub fn command(&self, buf: &[u8]) -> Result<String, FieldError>
pub fn command(&self, buf: &[u8]) -> Result<String, FieldError>
Returns the command verb (for client commands).
Errors
Returns FieldError::InvalidValue if the payload is not valid UTF-8.
Sourcepub fn args(&self, buf: &[u8]) -> Result<String, FieldError>
pub fn args(&self, buf: &[u8]) -> Result<String, FieldError>
Returns the command arguments.
Errors
Returns FieldError::InvalidValue if the payload is not valid UTF-8.
pub fn get_field( &self, buf: &[u8], name: &str, ) -> Option<Result<FieldValue, FieldError>>