UdpBuilder

Struct UdpBuilder 

pub struct UdpBuilder { /* private fields */ }
Builder for UDP packets.

Implementations

Source

impl UdpBuilder

pub fn new() -> Self

Create a new UDP builder with default values.

pub fn from_bytes(data: &[u8]) -> Result<Self, FieldError>

Create a builder initialized from an existing packet.

pub fn src_port(self, port: u16) -> Self

Set the source port.

pub fn sport(self, port: u16) -> Self

Alias for src_port (Scapy compatibility).

pub fn dst_port(self, port: u16) -> Self

Set the destination port.

pub fn dport(self, port: u16) -> Self

Alias for dst_port (Scapy compatibility).

pub fn length(self, len: u16) -> Self

Set the UDP length manually.

If not set, the length will be calculated automatically (8 + payload length).

pub fn len(self, len: u16) -> Self

Alias for length (Scapy compatibility).

pub fn checksum(self, csum: u16) -> Self

Set the checksum manually.

If not set, the checksum will be calculated automatically if IP addresses are provided.

pub fn chksum(self, csum: u16) -> Self

Alias for checksum (Scapy compatibility).

pub fn enable_auto_length(self) -> Self

Enable automatic length calculation (default).

pub fn disable_auto_length(self) -> Self

Disable automatic length calculation.

pub fn enable_auto_checksum(self) -> Self

Enable automatic checksum calculation (default).

pub fn disable_auto_checksum(self) -> Self

Disable automatic checksum calculation.

pub fn src_ipv4(self, addr: Ipv4Addr) -> Self

Set source IPv4 address for checksum calculation.

pub fn dst_ipv4(self, addr: Ipv4Addr) -> Self

Set destination IPv4 address for checksum calculation.

pub fn src_ipv6(self, addr: Ipv6Addr) -> Self

Set source IPv6 address for checksum calculation.

pub fn dst_ipv6(self, addr: Ipv6Addr) -> Self

Set destination IPv6 address for checksum calculation.

pub fn ipv4_addrs(self, src: Ipv4Addr, dst: Ipv4Addr) -> Self

Set both source and destination IPv4 addresses.

pub fn ipv6_addrs(self, src: Ipv6Addr, dst: Ipv6Addr) -> Self

Set both source and destination IPv6 addresses.

pub fn payload<T: Into<Vec<u8>>>(self, data: T) -> Self

Set the payload data.

pub fn append_payload<T: AsRef<[u8]>>(self, data: T) -> Self

Append to the payload data.

pub fn packet_size(&self) -> usize

Get the total packet size (header + payload).

pub fn header_size(&self) -> usize

Get the header size (always 8 bytes for UDP).

pub fn build(&self) -> Vec<u8>

Build the UDP packet into a new buffer.

pub fn build_into(&self, buf: &mut [u8]) -> Result<usize, FieldError>

Build the UDP packet into an existing buffer.

pub fn build_header(&self) -> Vec<u8>

Build just the UDP header (without payload).

Source

impl UdpBuilder

pub fn dns_query() -> Self

Create a DNS query packet builder (port 53).

pub fn dhcp_client() -> Self

Create a DHCP client packet builder (ports 68 -> 67).

pub fn dhcp_server() -> Self

Create a DHCP server packet builder (ports 67 -> 68).

pub fn ntp() -> Self

Create a NTP packet builder (port 123).