PCAP file I/O for reading and writing packet captures.
Provides rdpcap for reading all packets from a file,
PcapIterator for streaming large captures, and wrpcap for writing.
Re-exports
pub use reader::PcapIterator;pub use reader::rdpcap;pub use writer::wrpcap;pub use writer::wrpcap_packets;
Modules
Structs
- Captured
Packet - A captured packet with associated PCAP metadata.
- Link
Type - PCAP link-layer type.
- Pcap
Metadata - Metadata from a PCAP packet record.